=======
Credits
=======

Development Lead
----------------

* Per Sillrén <pers@spotify.com>

Contributors
------------

- Per Sillrén <pers@spotify.com>
- Chris Halpert (co-creator)
- Eskil Forsell
- Jeremy Salfen
- Kevin Mercurio